==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/ProxyListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProxyListBuilder extends io.fabric8.openshift.api.model.ProxyListFluentImpl<io.fabric8.openshift.api.model.ProxyListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ProxyList,io.fabric8.openshift.api.model.ProxyListBuilder>{
  public ProxyListBuilder() {
    this(false);
  }
  public ProxyListBuilder(java.lang.Boolean validationEnabled) {
    this(new ProxyList(), validationEnabled);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProxyList(), validationEnabled);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,io.fabric8.openshift.api.model.ProxyList instance) {
    this(fluent, instance, false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,io.fabric8.openshift.api.model.ProxyList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyList instance) {
    this(instance,false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ProxyListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ProxyList build() {
    ProxyList buildable = new ProxyList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProxyListBuilder that = (ProxyListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ProxyListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProxyListBuilder extends io.fabric8.openshift.api.model.ProxyListFluentImpl<io.fabric8.openshift.api.model.ProxyListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ProxyList,io.fabric8.openshift.api.model.ProxyListBuilder>{
  public ProxyListBuilder() {
    this(false);
  }
  public ProxyListBuilder(java.lang.Boolean validationEnabled) {
    this(new ProxyList(), validationEnabled);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProxyList(), validationEnabled);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,io.fabric8.openshift.api.model.ProxyList instance) {
    this(fluent, instance, false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyListFluent<?> fluent,io.fabric8.openshift.api.model.ProxyList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyList instance) {
    this(instance,false);
  }
  public ProxyListBuilder(io.fabric8.openshift.api.model.ProxyList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ProxyListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ProxyList build() {
    ProxyList buildable = new ProxyList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProxyListBuilder that = (ProxyListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
